@@ -53,7 +53,7 @@ ScreenInfo Scr;		        /* structures for the screen */
 Display *dpy;			/* which display are we talking to */
 
 Window BlackoutWin=None;        /* window to hide window captures */
-
+Bool fFvwmInStartup = True;     /* Set to False when startup has finished */
 
 char *default_config_command = "Read "FVWMRC;
 
@@ -61,7 +61,10 @@ char *default_config_command = "Read "FVWMRC;
 static char *config_commands[MAX_CFG_CMDS];
 static int num_config_commands=0;
 
+#if 0
+/* unsused */
 char *output_file = NULL;
+#endif
 
 XErrorHandler FvwmErrorHandler(Display *, XErrorEvent *);
 XIOErrorHandler CatchFatal(Display *);
@@ -186,12 +189,15 @@ int main(int argc, char **argv)
         fvwm_msg(ERR,"main","only %d -f and -cmd parms allowed!",MAX_CFG_CMDS);
       }
     }
+#if 0
+/* unused */
     else if (strncasecmp(argv[i],"-outfile",8)==0)
     {
       if (++i >= argc)
         usage();
       output_file = argv[i];
     }
+#endif
     else if (strncasecmp(argv[i],"-h",2)==0)
     {
       usage();
@@ -388,11 +394,13 @@ int main(int argc, char **argv)
   {
     Scr.gray_pixmap =
       XCreatePixmapFromBitmapData(dpy,Scr.Root,g_bits, g_width,g_height,
-                                  Scr.DefaultMenuFace->MenuColors.fore,Scr.DefaultMenuFace->MenuColors.back,
+                                  Scr.DefaultMenuFace->MenuColors.fore,
+				  Scr.DefaultMenuFace->MenuColors.back,
                                   Scr.d_depth);
     Scr.light_gray_pixmap =
       XCreatePixmapFromBitmapData(dpy,Scr.Root,l_g_bits,l_g_width,l_g_height,
-                                  Scr.DefaultMenuFace->MenuColors.fore,Scr.DefaultMenuFace->MenuColors.back,
+                                  Scr.DefaultMenuFace->MenuColors.fore,
+				  Scr.DefaultMenuFace->MenuColors.back,
                                   Scr.d_depth);
   }
 
@@ -463,6 +471,9 @@ int main(int argc, char **argv)
   MyXUngrabServer(dpy);
   UnBlackoutScreen(); /* if we need to remove blackout window */
   CoerceEnterNotifyOnCurrentWindow();
+  /* Make sure we have the correct click time now. */
+  if (Scr.ClickTime < 0)
+    Scr.ClickTime = -Scr.ClickTime;
   DBUG("main","Entering HandleEvents loop...");
   HandleEvents();
   DBUG("main","Back from HandleEvents loop?  Exitting...");
@@ -481,11 +492,12 @@ void StartupStuff(void)
 
   CaptureAllWindows();
   MakeMenus();
+#ifndef NON_VIRTUAL
+  /* Have to do this here too because preprocessor modules have not run to the
+   * end when HandleEvents is entered from the main loop. */
+  checkPanFrames();
+#endif
 
-  /* Dominik Vogt (8-Nov-1998): Scr.ClickTime patch to speed up InitFunction
-   * and RestartFunction (this can save quite a few seconds). */
-  if (Scr.ClickTime > 0)
-    Scr.ClickTime = -Scr.ClickTime;
   if(Restarting)
   {
     mr = FindPopup("RestartFunction");
@@ -498,8 +510,6 @@ void StartupStuff(void)
     if(mr != NULL)
       ExecuteFunction("Function InitFunction",NULL,&Event,C_ROOT,-1);
   }
-  if (Scr.ClickTime < 0)
-    Scr.ClickTime = -Scr.ClickTime;
 } /* StartupStuff */
 
 
@@ -517,7 +527,7 @@ void CaptureAllWindows(void)
   int i,j;
   unsigned int nchildren;
   Window root, parent, *children;
-  FvwmWindow *tmp,*next;		/* temp fvwm window structure */
+   FvwmWindow *tmp,*next;		/* temp fvwm window structure */
   Window w;
   unsigned long data[1];
   unsigned char *prop;
@@ -1255,7 +1265,8 @@ void InitVariables(void)
   Scr.ScrollResistance = Scr.MoveResistance = 0;
   Scr.SnapAttraction = 0;
   Scr.OpaqueSize = 5;
-  Scr.ClickTime = 150;
+  /* ClickTime is set to the positive value upon entering the event loop. */
+  Scr.ClickTime = -150;
   Scr.ColormapFocus = COLORMAP_FOLLOWS_MOUSE;
 
   /* set major operating modes */
@@ -1279,7 +1290,7 @@ void InitVariables(void)
   Scr.ModifyUSP                          =  True;
   Scr.CaptureHonorsStartsOnPage          =  True;
   Scr.RecaptureHonorsStartsOnPage        =  False;
-  Scr.ActivePlacementHonorsStartsOnPage  =  False;
+  Scr.ActivePlacementHonorsStartsOnPage  =  True;
 
   /* Not the right place for this, should only be called once somewhere .. */
   InitPictureCMap(dpy,Scr.Root);
